# orthofinder

**DOI:** [10.5281/zenodo.13787523](https://doi.org/10.5281/zenodo.13787523)

## Available Versions
- **Version 2.5.5**
  - [Download](https://zenodo.org/record/13787524/files/orthofinder_2.5.5.img)
  - **MD5:** `24b9b603bd5d8a6633682657c6016f96`
  - **DOI:** [10.5281/zenodo.13787524](https://doi.org/10.5281/zenodo.13787524)
  - **Size:** 472.86 MB
  - **Binaries:** 0 available

## Binaries (3 total)

```orthofinder diamond mmseqs```
